@@ -4,7 +4,6 @@
 #include "config.h"
 #include "portab.h"
 #include "graphics.h"
-#include "surface.h"
 #include "ags.h"
 #include "sprite.h"
 
@@ -45,7 +44,7 @@ struct _night {
 
 	MyRectangle updaterect;
 
-	int fonttype;
+	FontType fonttype;
 	int fontsize;
 
 	sprite_t *sp[SPRITEMAX];
@@ -55,7 +54,7 @@ struct _night {
 
 	// msg
 	char msgbuf[MSGBUFMAX];
-	boolean zhiding;
+	bool zhiding;
 	struct {
 		void (* cbmove)(agsevent_t *);
 		void (* cbrelease)(agsevent_t *);
