@@ -44,17 +44,17 @@
 #include "image.h"
 #include "debugger.h"
 
-static boolean need_update = TRUE;
-static boolean fade_outed = FALSE;
+static bool need_update = true;
+static bool fade_outed = false;
 static int cursor_move_time = 50; /* カーソル移動にかかる時間(ms) */
 
 static void palette_changed(void) {
-	nact->ags.pal_changed = TRUE;
+	nact->ags.pal_changed = true;
 	dbg_on_palette_change();
 }
 
 static void initPal(void) {
-	static const Color initial_palette[256] = {
+	static const SDL_Color initial_palette[256] = {
 		[  0] = {  0,   0,   0},
 		[  1] = {128,   0,   0},
 		[  2] = {  0, 128,   0},
@@ -78,18 +78,21 @@ static void initPal(void) {
 		[255] = {255, 255, 255},
 	};
 	memcpy(nact->ags.pal, initial_palette, sizeof(initial_palette));
+	for (int i = 0; i < 256; i++) {
+		nact->ags.pal[i].a = 255;
+	}
 	sdl_setPalette(nact->ags.pal, 0, 256);
 	palette_changed();
 }
 
-boolean ags_check_param(int *x, int *y, int *w, int *h) {
+bool ags_check_param(int *x, int *y, int *w, int *h) {
 	if (*x >= nact->ags.world_size.width) {
 		WARNING("Illegal Param x = %d (max=%d)(@%03x:%05x)", *x, nact->ags.world_size.width, sl_getPage(), sl_getIndex());
-		return FALSE;
+		return false;
 	}
 	if (*y >= nact->ags.world_size.height) {
 		WARNING("Illegal Param y = %d (max=%d)", *y, nact->ags.world_size.height);
-		return FALSE;
+		return false;
 	}
 	
 	if (*x < 0) { *w += *x; *x = 0; }
@@ -98,26 +101,26 @@ boolean ags_check_param(int *x, int *y, int *w, int *h) {
 	if ((*x + *w) > nact->ags.world_size.width)  { *w = nact->ags.world_size.width  - *x;}
 	if ((*y + *h) > nact->ags.world_size.height) { *h = nact->ags.world_size.height - *y;}
 	
-	if (*w <= 0) return FALSE;
-	if (*h <= 0) return FALSE;
+	if (*w <= 0) return false;
+	if (*h <= 0) return false;
 	
-	return TRUE;
+	return true;
 }
 
-boolean ags_check_param_xy(int *x, int *y) {
+bool ags_check_param_xy(int *x, int *y) {
 	if (*x >= nact->ags.world_size.width) {
 		WARNING("Illegal Param x = %d", *x);
-		return FALSE;
+		return false;
 	}
 	if (*y >= nact->ags.world_size.height) {
 		WARNING("Illegal Param y = %d", *y);
-		return FALSE;
+		return false;
 	}
 	
 	if (*x < 0) { *x = 0; }
 	if (*y < 0) { *y = 0; }
 	
-	return TRUE;
+	return true;
 }
 
 void ags_init(const char *render_driver, bool enable_zb) {
@@ -130,6 +133,9 @@ void ags_init(const char *render_driver, bool enable_zb) {
 	nact->ags.view_area.w = SYS35_DEFAULT_WIDTH;
 	nact->ags.view_area.h = SYS35_DEFAULT_HEIGHT;
 
+	nact->ags.font_type = FONT_GOTHIC;
+	nact->ags.text_decoration_type = 0;
+	nact->ags.text_decoration_color = 0;
 	nact->ags.enable_zb = enable_zb;
 	nact->ags.font_weight = enable_zb ? FONT_WEIGHT_BOLD : FONT_WEIGHT_NORMAL;
 	
@@ -141,7 +147,7 @@ void ags_init(const char *render_driver, bool enable_zb) {
 }
 
 void ags_remove(void) {
-	ags_autorepeat(TRUE);
+	ags_autorepeat(true);
 	sdl_Remove();
 }
 
@@ -172,7 +178,7 @@ void ags_setWorldSize(int width, int height, int depth) {
 		memset(nact->ags.dib->alpha, 255, width * height);
 	}
 	
-	fade_outed = FALSE;  /* thanx tajiri@wizard */
+	fade_outed = false;  /* thanx tajiri@wizard */
 	
 	palette_changed();
 }
@@ -207,7 +213,7 @@ void ags_getWindowInfo(DispInfo *info) {
 	sdl_getWindowInfo(info);
 }
 
-void ags_setExposeSwitch(boolean expose) {
+void ags_setExposeSwitch(bool expose) {
 	need_update = expose;
 }
 
@@ -239,7 +245,7 @@ void ags_updateFull() {
 	sdl_updateArea(&r, &p);
 }
 
-void ags_setPalettes(Color *src, int dst, int cnt) {
+void ags_setPalettes(SDL_Color *src, int dst, int cnt) {
 	for (int i = 0; i < cnt; i++) {
 		nact->ags.pal[dst + i] = src[i];
 	}
@@ -332,14 +338,14 @@ void ags_changeColorArea(int sx, int sy, int w, int h, int dst, int src, int cnt
 	if (!ags_check_param(&sx, &sy, &w, &h)) return;
 	
 	{
-		agsurface_t *dib = nact->ags.dib;
+		surface_t *dib = nact->ags.dib;
 		int   x, y;
 		int   src_last = src + cnt,dif = dst - src;
 		uint8_t *yl;
 		uint8_t *sdata = GETOFFSET_PIXEL(dib, sx, sy);
 		
 		for (y = 0; y < h; y++) {
-			yl = sdata + y * dib->bytes_per_line;
+			yl = sdata + y * dib->sdl_surface->pitch;
 			for (x = 0; x < w; x++) {
 				if (*yl >= src && *yl < src_last) *yl += dif;
 				yl++;
@@ -376,47 +382,92 @@ void ags_delRegion(void *region) {
 	sdl_delRegion(region);
 }
 
-MyRectangle ags_drawString(int x, int y, const char *src, int col) {
-	if (!ags_check_param_xy(&x, &y)) return (MyRectangle){};
+int ags_drawString(int x, int y, const char *src, int col, MyRectangle *rect_out) {
+	if (!ags_check_param_xy(&x, &y)) {
+		if (rect_out) {
+			rect_out->x = x;
+			rect_out->y = y;
+			rect_out->w = 0;
+			rect_out->h = 0;
+		}
+		return 0;
+	}
 	
+	MyRectangle adj;
 	char *utf8 = toUTF8(src);
+	switch(nact->ags.text_decoration_type) {
+	case TEXT_DECORATION_NONE:
+	default:
+		adj.x = 0; adj.y = 0; adj.w = 0; adj.h = 0;
+		break;
+	case TEXT_DECORATION_DROP_SHADOW_BOTTOM:
+		sdl_drawString(x, y +1, utf8, nact->ags.text_decoration_color);
+		adj.x = 0; adj.y = 0; adj.w = 0; adj.h = 1;
+		break;
+	case TEXT_DECORATION_DROP_SHADOW_RIGHT:
+		sdl_drawString(x +1, y, utf8, nact->ags.text_decoration_color);
+		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 0;
+		break;
+	case TEXT_DECORATION_DROP_SHADOW_BOTTOM_RIGHT:
+		sdl_drawString(x +1, y +1, utf8, nact->ags.text_decoration_color);
+		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 1;
+		break;
+	case TEXT_DECORATION_OUTLINE:
+		sdl_drawString(x -1, y, utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x +1, y, utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x, y -1, utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x, y +1, utf8, nact->ags.text_decoration_color);
+		adj.x = -1; adj.y = -1; adj.w = 2; adj.h = 2;
+		break;
+	case TEXT_DECORATION_BOLD_HORIZONTAL:
+		sdl_drawString(x +1, y, utf8, col);
+		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 0;
+		break;
+	case TEXT_DECORATION_BOLD_VERTICAL:
+		sdl_drawString(x, y +1, utf8, col);
+		adj.x = 0; adj.y = 0; adj.w = 0; adj.h = 1;
+		break;
+	case TEXT_DECORATION_BOLD_HORIZONTAL_VERTICAL:
+		sdl_drawString(x +1, y +1, utf8, col);
+		adj.x = 0; adj.y = 0; adj.w = 1; adj.h = 1;
+		break;
+	case TEXT_DECORATION_DROP_SHADOW_OUTLINE:
+		sdl_drawString(x -1, y   , utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x +1, y   , utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x   , y -1, utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x   , y +1, utf8, nact->ags.text_decoration_color);
+		sdl_drawString(x +2, y +2, utf8, nact->ags.text_decoration_color);
+		adj.x = -1; adj.y = -1; adj.w = 3; adj.h = 3;
+		break;
+	}
 	SDL_Rect r = sdl_drawString(x, y, utf8, col);
+	if (rect_out) {
+		rect_out->x = r.x + adj.x;
+		rect_out->y = r.y + adj.y;
+		rect_out->w = r.w + adj.w;
+		rect_out->h = r.h + adj.h;
+	}
 	free(utf8);
-
-	return (MyRectangle){r.x, r.y, r.w, r.h};
+	return r.w;
 }
 
-agsurface_t *ags_drawStringToSurface(const char *str) {
-	static SDL_Surface *fs;
-	static agsurface_t result;
-	if (fs) {
-		SDL_FreeSurface(fs);
-		fs = NULL;
-	}
-
+SDL_Surface *ags_drawStringToSurface(const char *str, int r, int g, int b) {
 	char *utf8 = toUTF8(str);
-	fs = font_get_glyph(utf8);
+	SDL_Surface *sf = font_get_glyph(utf8, r, g, b);
 	free(utf8);
-
-	result.depth = fs->format->BitsPerPixel;
-	result.bytes_per_pixel = fs->format->BytesPerPixel;
-	result.bytes_per_line = fs->pitch;
-	result.pixel = fs->pixels;
-	result.width = fs->w;
-	result.height = fs->h;
-	return &result;
+	return sf;
 }
 
 void ags_drawCg(cgdata *cg, int x, int y, int brightness, int sprite_color, bool alpha_blend) {
 	switch (cg->depth) {
 	case 8:
-		sdl_drawImage8_fromData(cg, x, y, sprite_color);
+		sdl_drawImage8(cg, x, y, sprite_color);
 		break;
 	case 16:
-		sdl_drawImage16_fromData(cg, x, y, brightness, alpha_blend);
+		sdl_drawImage16(cg, nact->ags.dib, x, y, brightness, alpha_blend);
 		break;
 	case 24:
-		sdl_drawImage24_fromData(cg, x, y, brightness);
+		sdl_drawImage24(cg, nact->ags.dib, x, y, brightness);
 		break;
 	}
 }
@@ -539,7 +590,7 @@ void ags_alpha_setPixel(int x, int y, int w, int h, uint8_t *b) {
 	alpha_set_pixels(nact->ags.dib, x, y, w, h, b + offset, savew);
 }
 
-void ags_runEffect(int duration_ms, boolean cancelable, ags_EffectStepFunc step, void *arg) {
+void ags_runEffect(int duration_ms, bool cancelable, ags_EffectStepFunc step, void *arg) {
 	unsigned wflags = cancelable ? KEYWAIT_CANCELABLE : KEYWAIT_NONCANCELABLE;
 	int start = sdl_getTicks();
 	for (int t = 0; t < duration_ms; t = sdl_getTicks() - start) {
@@ -553,7 +604,7 @@ void ags_runEffect(int duration_ms, boolean cancelable, ags_EffectStepFunc step,
 	step(arg, 1.0);
 }
 
-static void fade(int duration, boolean cancelable, enum sdl_effect_type type) {
+static void fade(int duration, bool cancelable, enum sdl_effect_type type) {
 	nact->waitcancel_key = 0;
 
 	SDL_Rect rect = {0, 0, nact->ags.view_area.w, nact->ags.view_area.h};
@@ -565,8 +616,8 @@ static void fade(int duration, boolean cancelable, enum sdl_effect_type type) {
 	sdl_effect_finish(eff);
 }
 
-void ags_fadeIn(int rate, boolean flag) {
-	fade_outed = FALSE;
+void ags_fadeIn(int rate, bool flag) {
+	fade_outed = false;
 	if (nact->ags.world_depth == 8)
 		sdl_setPalette(nact->ags.pal, 0, 256);
 
@@ -579,22 +630,24 @@ void ags_fadeIn(int rate, boolean flag) {
 	sdl_updateAll(&nact->ags.view_area);
 }
 
-void ags_fadeOut(int rate, boolean flag) {
+void ags_fadeOut(int rate, bool flag) {
 	if (need_update && !fade_outed) {
 		int duration = rate * 16 * 1000 / 60;
 		fade(duration, flag, nact->ags.world_depth == 8 ? EFFECT_FADEOUT : EFFECT_DITHERING_FADEOUT);
 	}
-	fade_outed = TRUE;
+	fade_outed = true;
 
 	if (nact->ags.world_depth == 8) {
-		Color pal[256];
-		memset(&pal, 0, sizeof(pal));
+		SDL_Color pal[256];
+		for (int i = 0; i < 256; i++) {
+			pal[i] = (SDL_Color){0, 0, 0, 255};
+		}
 		sdl_setPalette(pal, 0, 256);
 	}
 }
 
-void ags_whiteIn(int rate, boolean flag) {	
-	fade_outed = FALSE;
+void ags_whiteIn(int rate, bool flag) {	
+	fade_outed = false;
 	if (nact->ags.world_depth == 8)
 		sdl_setPalette(nact->ags.pal, 0, 256);
 
@@ -607,28 +660,36 @@ void ags_whiteIn(int rate, boolean flag) {
 	sdl_updateAll(&nact->ags.view_area);
 }
 
-void ags_whiteOut(int rate, boolean flag) {
+void ags_whiteOut(int rate, bool flag) {
 	if (need_update && !fade_outed) {
 		int duration = rate * 16 * 1000 / 60;
 		fade(duration, flag, nact->ags.world_depth == 8 ? EFFECT_WHITEIN : EFFECT_DITHERING_WHITEOUT);
 	}
-	fade_outed = TRUE;
+	fade_outed = true;
 
 	if (nact->ags.world_depth == 8) {
-		Color pal[256];
+		SDL_Color pal[256];
 		memset(&pal, 255, sizeof(pal));
 		sdl_setPalette(pal, 0, 256);
 	}
 }
 
-void ags_setFont(int type, int size) {
+void ags_setFont(FontType type, int size) {
 	font_select(type, size, FONT_WEIGHT_NORMAL);
 }
 
-void ags_setFontWithWeight(int type, int size, int weight) {
+void ags_setFontWithWeight(FontType type, int size, int weight) {
 	font_select(type, size, weight);
 }
 
+void ags_setTextDecorationType(TextDecorationType type) {
+	nact->ags.text_decoration_type = type;
+}
+
+void ags_setTextDecorationColor(int col) {
+	nact->ags.text_decoration_color = col;
+}
+
 void ags_setCursorType(int type) {
 	if (nact->ags.noimagecursor && type >= 100) return;
 	sdl_setCursorType(type);
@@ -679,13 +740,13 @@ void ags_setCursorLocation(int x, int y, bool is_dibgeo, bool for_selection) {
 }
 
 EMSCRIPTEN_KEEPALIVE
-void ags_setAntialiasedStringMode(boolean on) {
+void ags_setAntialiasedStringMode(bool on) {
 	if (!nact->ags.noantialias) {
 		font_set_antialias(on);
 	}
 }
 
-boolean ags_getAntialiasedStringMode() {
+bool ags_getAntialiasedStringMode() {
 	return font_get_antialias();
 }
 
@@ -708,10 +769,38 @@ int ags_getCursorMoveTime() {
 	 return cursor_move_time;
 }
 
-agsurface_t *ags_getDIB() {
+surface_t *ags_getDIB() {
 	return nact->ags.dib;
 }
 
-void ags_autorepeat(boolean enable) {
+void ags_autorepeat(bool enable) {
 	sdl_setAutoRepeat(enable);
 }
+
+bool ags_clipCopyRect(const MyRectangle *sw, const MyRectangle *dw, int *sx, int *sy, int *dx, int *dy, int *w, int *h) {
+	// Clip source rectangle to source window
+	SDL_Rect sr = {*sx, *sy, *w, *h};
+	if (!SDL_IntersectRect(&sr, sw, &sr))
+		return false;
+
+	// Shift destination rectangle if source origin has changed
+	int dx_ = *dx + (sr.x - *sx);
+	int dy_ = *dy + (sr.y - *sy);
+
+	// Clip destination rectangle to destination window
+	SDL_Rect dr = {dx_, dy_, sr.w, sr.h};
+	if (!SDL_IntersectRect(&dr, dw, &dr))
+		return false;
+
+	// Shift source rectangle if destination origin has changed
+	sr.x += dr.x - dx_;
+	sr.y += dr.y - dy_;
+
+	*sx = sr.x;
+	*sy = sr.y;
+	*w = dr.w;
+	*h = dr.h;
+	*dx = dr.x;
+	*dy = dr.y;
+	return true;
+}
