@@ -32,6 +32,7 @@
 #include "selection.h"
 #include "message.h"
 #include "input.h"
+#include "sdl_core.h"
 
 static void undeferr();
 
@@ -174,13 +175,15 @@ static void message(int c0) {
 }
 
 void exec_command(void) {
-	DEBUG_MESSAGE("%d:%x\n", sl_getPage(), sl_getIndex());
+	TRACE_MESSAGE("%d:%x\n", sl_getPage(), sl_getIndex());
 
 	int page, index;
 	int c0 = sl_getc();
 
-	if (c0 == BREAKPOINT)
+	if (c0 == BREAKPOINT) {
+		sdl_updateScreen();
 		c0 = dbg_handle_breakpoint(sl_getPage(), sl_getIndex() - 1);
+	}
 
 	if (c0 == 0x20 || c0 >= 0x80) {
 		message(c0);
@@ -211,10 +214,10 @@ void exec_command(void) {
 		/* 選択肢の登録 */
 		if (nact->sel.in_setting) {
 			sel_fixElement();
-			nact->sel.in_setting = FALSE;
+			nact->sel.in_setting = false;
 		} else {
 			sel_addRetValue(sl_getaddr());
-			nact->sel.in_setting = TRUE;
+			nact->sel.in_setting = true;
 		}
 		break;
 	case '%':
@@ -534,8 +537,8 @@ void exec_command(void) {
 	case 'A':
 		/* hit Any Key */
 		sys_hit_any_key();
-		msg_nextPage(TRUE);
-		DEBUG_COMMAND("A");
+		msg_nextPage(true);
+		TRACE("A");
 		break;
 	case 'B':
 		switch(sl_getc()) {
@@ -949,7 +952,7 @@ void exec_command(void) {
 		break;
 	case 'R':
 		/* 改行 */
-		DEBUG_MESSAGE("\n");
+		TRACE_MESSAGE("\n");
 		msg_nextLine();
 		break;
 	case 'S':
@@ -1085,7 +1088,7 @@ void exec_command(void) {
 	{
 		int num=getCaliValue();
 		sys_addMsg(svar_get(num));
-		DEBUG_COMMAND("X %d:", num);
+		TRACE("X %d:", num);
 	}
 		break;
 	case 'Y':
