@@ -28,6 +28,7 @@
 #include <sys/time.h>
 #include "portab.h"
 #include "sdl_core.h"
+#include "scheduler.h"
 #include "xsystem35.h"
 #include "scenario.h"
 #include "ags.h"
@@ -42,8 +43,8 @@ typedef struct {
 	int nxUnit;
 	int nyUnit;
 	int bSpCol;
-	boolean fEnable;
-	boolean useTTP;
+	bool fEnable;
+	bool useTTP;
 	int TTPunit;
 } UnitMapSrcImg;
 
@@ -70,9 +71,9 @@ typedef struct {
 	int preY;
 	int curX;          /* 現在位置 */
 	int curY;
-	boolean draw;      /* UNITを描く？ */
-	boolean nomove;    /* 移動あり・なし */
-	boolean rewrite;   /* 画面更新の必要あり */
+	bool draw;      /* UNITを描く？ */
+	bool nomove;    /* 移動あり・なし */
+	bool rewrite;   /* 画面更新の必要あり */
 } VaParam;
 
 typedef struct {
@@ -109,10 +110,7 @@ static UnitMapSrcImg *srcimg;
 #define VA_RUNNING     1
 #define VACMD_MAX 20                      /* Panyoで18まで */
 static  VaParam VAcmd[VACMD_MAX];         
-static  boolean inAnimation      = FALSE; /* 画面更新中 */
-#ifdef __EMSCRIPTEN__
-static int status_check_count;
-#endif
+static  bool inAnimation      = false; /* 画面更新中 */
 
 /* UnitMap 各種マクロ */
 #define MAPSIZE_PER_ATTRIB (cxMap * cyMap)
@@ -128,7 +126,7 @@ static int status_check_count;
 #define UNITMAP_WALKPAINT_PAGETOP(page)  UNITMAP_WALKPAINT((page),0,0)
 #define UNITMAP_WALKRESULT_PAGETOP(page) UNITMAP_WALKRESULT((page),0,0)
 
-static boolean vh_checkImmovableArea(int page, int x, int y, int w, int h);
+static bool vh_checkImmovableArea(int page, int x, int y, int w, int h);
 static void    vh_append_pos(int x, int y);
 static void    vh_copy_to_src();
 static void    vh_check_udlr(int n, int nPage, int x, int y);
@@ -148,7 +146,7 @@ void commandVC() { /* from Rance4 */
 	cxUnit   = getCaliValue();
 	cyUnit   = getCaliValue();
 	
-	DEBUG_COMMAND("VC %d,%d,%d,%d,%d,%d,%d:",nPageNum, x0Map, y0Map, cxMap, cyMap, cxUnit, cyUnit);
+	TRACE("VC %d,%d,%d,%d,%d,%d,%d:",nPageNum, x0Map, y0Map, cxMap, cyMap, cxUnit, cyUnit);
 	
 	if (NULL != UnitMap ) {
 		free(UnitMap);
@@ -186,7 +184,7 @@ void commandVP() { /* from T2 */
 	int nyUnit = getCaliValue();
 	int bSpCol = getCaliValue();
 	
-	DEBUG_COMMAND("VP %d,%d,%d,%d,%d,%d:",nPage, x0Unit, y0Unit, nxUnit, nyUnit, bSpCol);
+	TRACE("VP %d,%d,%d,%d,%d,%d:",nPage, x0Unit, y0Unit, nxUnit, nyUnit, bSpCol);
 	
 	if (nPage >= nPageNum) {
 		WARNING("VP nPage too large %d", nPage);
@@ -198,8 +196,8 @@ void commandVP() { /* from T2 */
 	srcimg[nPage].nxUnit = nxUnit;
 	srcimg[nPage].nyUnit = nyUnit;
 	srcimg[nPage].bSpCol = bSpCol;
-	srcimg[nPage].useTTP = FALSE;
-	srcimg[nPage].fEnable = TRUE;
+	srcimg[nPage].useTTP = false;
+	srcimg[nPage].fEnable = true;
 }
 
 void commandVS() { /* from Rance4 */
@@ -209,7 +207,7 @@ void commandVS() { /* from Rance4 */
 	int y     = getCaliValue();
 	int wData = getCaliValue();
 	
-	DEBUG_COMMAND("VS %d,%d,%d,%d,%d:",nPage, nType, x, y, wData);
+	TRACE("VS %d,%d,%d,%d,%d:",nPage, nType, x, y, wData);
 	
 	if (nPage >= nPageNum) {
 		WARNING("VS nPage too large %d", nPage);
@@ -259,7 +257,7 @@ void commandVG() { /* from Rance4 */
 	int x = getCaliValue();
 	int y = getCaliValue();
 	
-	DEBUG_COMMAND("VG %d,%d,%d,%d:",nPage, nType, x, y);
+	TRACE("VG %d,%d,%d,%d:",nPage, nType, x, y);
 
 	if (nPage >= nPageNum) {
 		WARNING("VG nPage too large %d", nPage);
@@ -303,7 +301,7 @@ void commandVH() { /* from Rance4 */
 	int xx, yy, i, n;
 	int maxfoot, lmtx, lmty, lmtw, lmth;
 	
-	DEBUG_COMMAND("VH %d,%d,%d,%d,%d,%d:",nPage, x, y, width, height, _max);
+	TRACE("VH %d,%d,%d,%d,%d,%d:",nPage, x, y, width, height, _max);
 	
 	if (nPage >= nPageNum) {
 		WARNING("VH nPage too large %d", nPage);
@@ -378,7 +376,7 @@ void commandVH() { /* from Rance4 */
 	vh_cnt_src = n = 1;
 	vh_cnt_dst = 0;
 	
-	while(TRUE) {
+	while(true) {
 		for (i = 0; i < vh_cnt_src; i++) {
 			vh_check_udlr(n, nPage, (vh_src + i)->x, (vh_src + i)->y);
 		}
@@ -418,12 +416,12 @@ void commandVF() { /* from Panyo */
 	for (i = 0; i < nPageNum; i++) {
 		img = &srcimg[i];
 		
-		if (img->fEnable == FALSE) continue;
+		if (!img->fEnable) continue;
 		
 		for (y = 0; y < cyMap; y++) {
 			for (x = 0; x < cxMap; x++) {
 				unit = *UNITMAP_UNITNUMBER(i, x, y);
-				if (img->useTTP == TRUE && img->TTPunit == unit) continue;
+				if (img->useTTP && img->TTPunit == unit) continue;
 				// printf("i = %d, x = %d, y = %d, unit no = %d\n", i, x, y,unit);
 				unit_x = unit % img->nxUnit;
 				unit_y = unit / img->nxUnit;
@@ -445,16 +443,16 @@ void commandVF() { /* from Panyo */
 	}
 	
 	ags_updateArea(x0Map, y0Map, cxMap * cxUnit, cyMap * cyUnit);
-	DEBUG_COMMAND("VF:");
+	TRACE("VF:");
 }
 
 void commandVV() { /* from T2 */
 	int nPage   = getCaliValue();
 	int fEnable = getCaliValue();
 	
-	DEBUG_COMMAND("VV %d,%d:",nPage, fEnable);
+	TRACE("VV %d,%d:",nPage, fEnable);
 	
-	srcimg[nPage].fEnable = (fEnable == 1 ? TRUE : FALSE);
+	srcimg[nPage].fEnable = fEnable == 1;
 }
 
 void commandVR() { /* from Rance4 */
@@ -463,7 +461,7 @@ void commandVR() { /* from Rance4 */
 	int *var  = getCaliVariable();
 	int *dst;
 	
-	DEBUG_COMMAND("VR %d,%d,%p:",nPage, nType, var);
+	TRACE("VR %d,%d,%p:",nPage, nType, var);
 	
 	if (nPage >= nPageNum) {
 		WARNING("VR nPage too large %d", nPage);
@@ -493,7 +491,7 @@ void commandVW() { /* from Rance4 */
 	int *var  = getCaliVariable();
 	int *src;
 	
-	DEBUG_COMMAND("VW %d,%d,%p:",nPage, nType, var);
+	TRACE("VW %d,%d,%p:",nPage, nType, var);
 	
 	if (nPage >= nPageNum) {
 		WARNING("VW nPage too large %d", nPage);
@@ -528,7 +526,7 @@ void commandVE() { /* from T2 */
 	int unit, unit_x, unit_y;
 	UnitMapSrcImg *img;
 	
-	DEBUG_COMMAND("VE %d,%d,%d,%d,%d,%d:", x, y, width, height, out_ptn, flag);
+	TRACE("VE %d,%d,%d,%d,%d,%d:", x, y, width, height, out_ptn, flag);
 	if (flag == 1) {
 		WARNING("VE flag1 is not yet");
 	}
@@ -536,7 +534,7 @@ void commandVE() { /* from T2 */
 	for (i = 0; i < nPageNum; i++) {
 		img = &srcimg[i];
 		/* VV による */
-		if (img->fEnable == FALSE) continue;
+		if (!img->fEnable) continue;
 		
 		for (yy = y; yy < (y+height); yy++) {
 			for (xx = x; xx < (x+width); xx++) {
@@ -546,7 +544,7 @@ void commandVE() { /* from T2 */
 					unit = *UNITMAP_UNITNUMBER(i, xx, yy);
 				}
 
-				if (img->useTTP == TRUE && img->TTPunit == unit) continue;
+				if (img->useTTP && img->TTPunit == unit) continue;
 				//printf("i = %d, xx = %d, yy = %d, unit no = %d\n", i, xx, yy,unit);
 				unit_x = unit % img->nxUnit;
 				unit_y = unit / img->nxUnit;
@@ -567,13 +565,13 @@ void commandVZ() { /* from T2 */
 	int p2 = getCaliValue();
 	int p3 = getCaliValue();
 	
-	DEBUG_COMMAND("VZ %d,%d,%d:", p1, p2, p3);
+	TRACE("VZ %d,%d,%d:", p1, p2, p3);
 	
 	switch(p1) {
 	case 0:
-		srcimg[p2].useTTP = FALSE; break;
+		srcimg[p2].useTTP = false; break;
 	case 1:
-		srcimg[p2].useTTP = TRUE;
+		srcimg[p2].useTTP = true;
 		srcimg[p2].TTPunit = p3;
 		break;
 	case 2:
@@ -593,7 +591,7 @@ void commandVX() { /* from T2 */
 	int p3 = getCaliValue();
 	int p4 = getCaliValue();
 	
-	DEBUG_COMMAND("VX %d,%d,%d,%d:", p1, p2, p3, p4);
+	TRACE("VX %d,%d,%d,%d:", p1, p2, p3, p4);
 	
 	switch(p1) {
 	case 0:
@@ -653,7 +651,7 @@ void commandVT() { /* from Panyo */
 		}
 	}
 	
-	DEBUG_COMMAND("VT %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", sp, sa, sx, sy, width, height, dp, da, dx, dy);
+	TRACE("VT %d,%d,%d,%d,%d,%d,%d,%d,%d,%d:", sp, sa, sx, sy, width, height, dp, da, dx, dy);
 }
 
 void commandVB() {
@@ -665,7 +663,7 @@ void commandVB() {
 	int y_size = getCaliValue();
 	int data   = getCaliValue();
 	
-	DEBUG_COMMAND_YET("VB %d,%d,%d,%d,%d,%d,%d:", page, type, x_pos, y_pos, x_size, y_size, data);
+	TRACE_UNIMPLEMENTED("VB %d,%d,%d,%d,%d,%d,%d:", page, type, x_pos, y_pos, x_size, y_size, data);
 }
 
 void commandVIC() { /* from Panyo */
@@ -677,15 +675,15 @@ void commandVIC() { /* from Panyo */
 	int x, y, i;
 	UnitMapSrcImg *img;
 
-	DEBUG_COMMAND("VIC %d,%d,%d,%d:", sx, sy, width, height);
+	TRACE("VIC %d,%d,%d,%d:", sx, sy, width, height);
 	
 	for (i = 0; i < nPageNum; i++) {
 		img = &srcimg[i];
-		if (img->fEnable == FALSE) continue;
+		if (!img->fEnable) continue;
 		for (y = 0; y < height; y++) {
 			for (x = 0; x < width; x++) {
 				unit = *UNITMAP_UNITNUMBER(i, sx + x, sy + y);
-				if (img->useTTP == TRUE && img->TTPunit == unit) continue;
+				if (img->useTTP && img->TTPunit == unit) continue;
 				//printf("i = %d, xx = %d, yy = %d, unit no = %d\n", i, xx, yy, unit);
 				unit_x = unit % img->nxUnit;
 				unit_y = unit / img->nxUnit;
@@ -706,7 +704,7 @@ void commandVIP() {
 	int width  = getCaliValue();
 	int height = getCaliValue();
 	
-	DEBUG_COMMAND_YET("VIP %d,%d,%d,%d:", x, y, width, height);
+	TRACE_UNIMPLEMENTED("VIP %d,%d,%d,%d:", x, y, width, height);
 }
 
 void commandVJ() {
@@ -716,16 +714,7 @@ void commandVJ() {
 	int y     = getCaliValue();
 	int max   = getCaliValue();
 	
-	DEBUG_COMMAND_YET("VJ %d,%d,%d,%d:", page, x, y, max);
-}
-
-static void throttle() {
-#ifdef __EMSCRIPTEN__
-	if (++status_check_count > 1) {
-		status_check_count = 0;
-		nact->wait_vsync = TRUE;
-	}
-#endif
+	TRACE_UNIMPLEMENTED("VJ %d,%d,%d,%d:", page, x, y, max);
 }
 
 void commandVA() { /* from Panyo */
@@ -737,11 +726,11 @@ void commandVA() { /* from Panyo */
 	if (no >= 10) {
 		var1 = getCaliVariable();
 		var2 = getCaliVariable();
-		DEBUG_COMMAND("VA %d,%d,%p,%p:", no, p1, var1, var2);
+		TRACE("VA %d,%d,%p,%p:", no, p1, var1, var2);
 	} else {
 		p2 = getCaliValue();
 		p3 = getCaliValue();
-		DEBUG_COMMAND("VA %d,%d,%d,%d:", no, p1, p2, p3);
+		TRACE("VA %d,%d,%d,%d:", no, p1, p2, p3);
 	}
 	
 	if (p1 > VACMD_MAX) {
@@ -754,9 +743,9 @@ void commandVA() { /* from Panyo */
 	case 0:
 		if (p2 == 0) {
 			/* 停止 */
-			inAnimation = TRUE;
+			inAnimation = true;
 			VAcmd[p1].state = VA_STOPPED;
-			VAcmd[p1].draw  = TRUE;
+			VAcmd[p1].draw  = true;
 			if (p3 == 0) {
 				/* ユニット消し */
 				va_restoreUnit(p1);
@@ -766,32 +755,32 @@ void commandVA() { /* from Panyo */
 				va_drawUnit(p1);
 				va_updateUnit(p1);
 			}
-			VAcmd[p1].draw  = FALSE;
+			VAcmd[p1].draw  = false;
 		} else {
 			/* 開始 (p3=コマ数,0:無限(開始位置==終了位置のとき))*/
-			inAnimation = TRUE;
+			inAnimation = true;
 			VAcmd[p1].elaspCut  = 0;
 			VAcmd[p1].startTime = sdl_getTicks();
 			VAcmd[p1].totalCut  = p3;
 			
 			if (p3 == 0) {
-				VAcmd[p1].nomove = TRUE;
+				VAcmd[p1].nomove = true;
 			} else {
 				if (VAcmd[p1].startX == VAcmd[p1].endX && VAcmd[p1].startY == VAcmd[p1].endY) {
-					VAcmd[p1].nomove = TRUE;
+					VAcmd[p1].nomove = true;
 				} else {
-					VAcmd[p1].nomove = FALSE;
+					VAcmd[p1].nomove = false;
 				}
 			}
 			/* animation start */
-			nact->is_va_animation = TRUE;
+			nact->is_va_animation = true;
 	
 			VAcmd[p1].state   = VA_RUNNING;
-			VAcmd[p1].draw    = TRUE;
+			VAcmd[p1].draw    = true;
 			va_drawUnit(p1);
 			va_updateUnit(p1);
 			if (p2 == 2) {
-				VAcmd[p1].rewrite = TRUE;
+				VAcmd[p1].rewrite = true;
 				/* キー抜け無し ,p3=0は指定不可 */
 				while(VAcmd[p1].state == VA_RUNNING) {
 					va_animationAlone(p1);
@@ -802,7 +791,7 @@ void commandVA() { /* from Panyo */
 			} else if (p2 == 3) {
 				/* キー抜けあり ,p3=0は指定不可*/
 				int key = 0;
-				VAcmd[p1].rewrite = TRUE;
+				VAcmd[p1].rewrite = true;
 				while(VAcmd[p1].state == VA_RUNNING) {
 					va_animationAlone(p1);
 					sdl_sleep(10);
@@ -852,33 +841,33 @@ void commandVA() { /* from Panyo */
 		/* 状態取得(var1=0:停止1:動,var2=番号) */
 		*var1 = VAcmd[p1].state == 0 ? 0 : 1;
 		*var2 = VAcmd[p1].elaspCut;
-		throttle();
+		scheduler_on_event(SCHEDULER_EVENT_VA_STATUS_CHECK);
 		break;
 	case 11:
 		/* 位置取得 */
 		*var1 = VAcmd[p1].curX;
 		*var2 = VAcmd[p1].curY;
-		throttle();
+		scheduler_on_event(SCHEDULER_EVENT_VA_STATUS_CHECK);
 		break;
 	default:
 		WARNING("Unknown VA command %d", no);
 	}
 }
 	
-static boolean vh_checkImmovableArea(int page, int x, int y, int w, int h) {
+static bool vh_checkImmovableArea(int page, int x, int y, int w, int h) {
 	int _x, _y;
 	
-	if (x + w > cxMap) return TRUE; 
+	if (x + w > cxMap) return true; 
 	
-	if (y + h > cyMap) return TRUE; 
+	if (y + h > cyMap) return true; 
 
 	for (_y = y; _y < (y+h); _y++) {
 		for (_x = x; _x < (x+w); _x++) {
-			if (*UNITMAP_WALKRESULT(page, _x, _y) == 255) return TRUE;
+			if (*UNITMAP_WALKRESULT(page, _x, _y) == 255) return true;
 		}
 	}
 	
-	return FALSE;
+	return false;
 }
 
 static void vh_append_pos(int x, int y) {
@@ -970,7 +959,7 @@ void va_animation(void) {
 
 	va_update();
 
-	inAnimation = TRUE;
+	inAnimation = true;
 	
 	for (i = 0; i < VACMD_MAX; i++) {
 		if (VAcmd[i].state == VA_STOPPED) continue;
@@ -983,10 +972,10 @@ void va_animation(void) {
 		h = max(VAcmd[i].curY + VAcmd[i].unitHeight, VAcmd[i].preY + VAcmd[i].unitHeight) - y; 
 		ags_updateArea(x, y, w, h);
 		// printf("x = %d, y = %d, w = %d, h = %d\n", x, y, w, h);
-		VAcmd[i].rewrite = FALSE;
+		VAcmd[i].rewrite = false;
 	}
 	
-	inAnimation = FALSE;
+	inAnimation = false;
 }
 	
 static void va_animationAlone(int i) {
@@ -996,7 +985,7 @@ static void va_animationAlone(int i) {
 
 	if (!VAcmd[i].rewrite) return;
 
-	inAnimation = TRUE;
+	inAnimation = true;
 	
 	va_restoreUnit(i);
 	va_drawUnit(i);
@@ -1007,24 +996,24 @@ static void va_animationAlone(int i) {
 	h = max(VAcmd[i].curY + VAcmd[i].unitHeight, VAcmd[i].preY + VAcmd[i].unitHeight) - y; 
 	ags_updateArea(x, y, w, h);
 	
-	VAcmd[i].rewrite = FALSE;
-	inAnimation = FALSE;
+	VAcmd[i].rewrite = false;
+	inAnimation = false;
 }
 
 static void va_update() {
-	boolean proceeding = FALSE;
+	bool proceeding = false;
 	int i;
 	int curTime = sdl_getTicks();
 	
 	for (i = 0; i < VACMD_MAX; i++) {
 		if (VAcmd[i].state == VA_RUNNING) {
-			proceeding = TRUE;
+			proceeding = true;
 			int cut = (curTime - VAcmd[i].startTime) / VAcmd[i].intervaltime;
 			
 			if (cut > VAcmd[i].elaspCut) {
 				/* まだ更新していない場合はskip */
 				if (VAcmd[i].rewrite) continue;
-				VAcmd[i].rewrite = TRUE;
+				VAcmd[i].rewrite = true;
 				VAcmd[i].elaspCut++;
 				/* 古い場所 */
 				VAcmd[i].preX = VAcmd[i].curX;
@@ -1044,11 +1033,8 @@ static void va_update() {
 	}
 	/* 更新するものが無い場合は、タイマーを止めて、アニメーションストップ */
 	if (!proceeding) {
-		nact->is_va_animation = FALSE;
+		nact->is_va_animation = false;
 	}
-#ifdef __EMSCRIPTEN__
-	status_check_count = 0;
-#endif
 }
 
 void va_reset(void) {
@@ -1074,5 +1060,5 @@ void va_reset(void) {
 	srcimg = NULL;
 
 	memset(VAcmd, 0, sizeof(VAcmd));
-	inAnimation = FALSE;
+	inAnimation = false;
 }
